@@ -8,7 +8,6 @@ use DBIx::Class::Carp;
 use Scope::Guard ();
 use Context::Preserve 'preserve_context';
 use Try::Tiny;
-use List::Util 'first';
 use namespace::clean;
 
 __PACKAGE__->sql_limit_dialect ('RowNum');
@@ -285,7 +284,7 @@ sub _dbh_execute {
   my ($self, $sql, $bind) = @_[0,2,3];
 
   # Turn off sth caching for multi-part LOBs. See _prep_for_execute below
-  local $self->{disable_sth_caching} = 1 if first {
+  local $self->{disable_sth_caching} = 1 if grep {
     ($_->[0]{_ora_lob_autosplit_part}||0)
       >
     (__cache_queries_with_max_lob_parts - 1)
@@ -399,7 +398,7 @@ sub connect_call_datetime_setup {
 }
 
 ### Note originally by Ron "Quinn" Straight <quinnfazigu@gmail.org>
-### http://git.shadowcat.co.uk/gitweb/gitweb.cgi?p=dbsrgits/DBIx-Class.git;a=commitdiff;h=5db2758de644d53e07cd3e05f0e9037bf40116fc
+### https://github.com/Perl5/DBIx-Class/commit/5db2758de6
 #
 # Handle LOB types in Oracle.  Under a certain size (4k?), you can get away
 # with the driver assuming your input is the deprecated LONG type if you
@@ -651,7 +650,7 @@ sub relname_to_table_alias {
 
   my $alias = $self->next::method(@_);
 
-  # we need to shorten here in addition to the shortening in SQLA itself,
+  # we need to shorten here in addition to the shortening in SQLMaker itself,
   # since the final relnames are crucial for the join optimizer
   return $self->sql_maker->_shorten_identifier($alias);
 }
